==> hs-bio-0.4.tbz: lib/bio-0.4/register.sh <==
#!/bin/sh

echo 'name: bio
version: 0.4
license: LGPL
copyright:
maintainer: ketil@ii.uib.no
stability:
homepage: http://blog.malde.org/index.php/the-haskell-bioinformatics-library/
package-url:
description: This is a collection of data structures and algorithms
             useful for building bioinformatics-related tools
             and utilities.
             .
             Current list of features includes: a Sequence data type supporting
             protein and nucleotide sequences and conversion between them.  As of version
             0.4, different kinds of sequence have different types.  Support for quality
             data, reading and writing Fasta formatted files, reading TwoBit and
             phd formats, and Roche/454 SFF files.  Rudimentary (i.e. unoptimized) support
             for doing alignments - including dynamic adjustment of scores based on sequence quality.
             Also Blast output parsing.  Partly implemented single linkage clustering, and
             multiple alignment.  Reading Gene Ontology (GO) annotations (GOA) and
             definitions\/hierarchy.
             .
             The Darcs repository is at: <http://malde.org/~ketil/biohaskell/biolib>.
category: Bioinformatics
author: Ketil Malde
exposed: True
exposed-modules: Bio.Sequence Bio.Sequence.SeqData
                 Bio.Sequence.Fasta Bio.Sequence.FastQ Bio.Sequence.TwoBit
                 Bio.Sequence.Phd Bio.Sequence.Entropy Bio.Sequence.HashWord
                 Bio.Sequence.GOA Bio.Sequence.GeneOntology Bio.Sequence.KEGG
                 Bio.Sequence.SFF Bio.Sequence.SFF_name Bio.Alignment.BlastData
                 Bio.Alignment.BlastFlat Bio.Alignment.Blast Bio.Alignment.BlastXML
                 Bio.Alignment.AlignData Bio.Alignment.Matrices Bio.Alignment.SAlign
                 Bio.Alignment.AAlign Bio.Alignment.QAlign Bio.Alignment.Multiple
                 Bio.Alignment.ACE Bio.Alignment.Bowtie Bio.Alignment.Soap
                 Bio.Clustering Bio.Util Bio.Util.Parsex Bio.Util.TestBase
                 Bio.Location.Strand Bio.Location.Position
                 Bio.Location.ContigLocation Bio.Location.Location
                 Bio.Location.LocMap Bio.Location.OnSeq Bio.Location.SeqLocation
                 Bio.Location.SeqLocMap Bio.GFF3.Escape Bio.GFF3.Feature
                 Bio.GFF3.FeatureHier Bio.GFF3.FeatureHierSequences Bio.GFF3.SGD
hidden-modules:
import-dirs: /usr/local/lib/bio-0.4/ghc-6.10.4
library-dirs: /usr/local/lib/bio-0.4/ghc-6.10.4
hs-libraries: HSbio-0.4
extra-libraries:
extra-ghci-libraries:
include-dirs:
includes:
depends: QuickCheck-1.2.0.0 array-0.2.0.0 base-3.0.3.1
         binary-0.5.0.2 bytestring-0.9.1.4 containers-0.2.0.1 mtl-1.1.0.2
         old-time-1.0.0.2 parallel-1.1.0.1 parsec-2.1.0.1 random-1.0.0.1
         tagsoup-0.6
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/bio-0.4/html/bio.haddock
haddock-html: /usr/local/share/doc/bio-0.4/html' | /usr/local/bin/ghc-pkg update -

==> hs-bio-0.4_1.tbz: lib/bio-0.4/register.sh <==
#!/bin/sh

echo 'name: bio
version: 0.4
license: LGPL
copyright:
maintainer: ketil@ii.uib.no
stability:
homepage: http://blog.malde.org/index.php/the-haskell-bioinformatics-library/
package-url:
description: This is a collection of data structures and algorithms
             useful for building bioinformatics-related tools
             and utilities.
             .
             Current list of features includes: a Sequence data type supporting
             protein and nucleotide sequences and conversion between them.  As of version
             0.4, different kinds of sequence have different types.  Support for quality
             data, reading and writing Fasta formatted files, reading TwoBit and
             phd formats, and Roche/454 SFF files.  Rudimentary (i.e. unoptimized) support
             for doing alignments - including dynamic adjustment of scores based on sequence quality.
             Also Blast output parsing.  Partly implemented single linkage clustering, and
             multiple alignment.  Reading Gene Ontology (GO) annotations (GOA) and
             definitions\/hierarchy.
             .
             The Darcs repository is at: <http://malde.org/~ketil/biohaskell/biolib>.
category: Bioinformatics
author: Ketil Malde
exposed: True
exposed-modules: Bio.Sequence Bio.Sequence.SeqData
                 Bio.Sequence.Fasta Bio.Sequence.FastQ Bio.Sequence.TwoBit
                 Bio.Sequence.Phd Bio.Sequence.Entropy Bio.Sequence.HashWord
                 Bio.Sequence.GOA Bio.Sequence.GeneOntology Bio.Sequence.KEGG
                 Bio.Sequence.SFF Bio.Sequence.SFF_name Bio.Alignment.BlastData
                 Bio.Alignment.BlastFlat Bio.Alignment.Blast Bio.Alignment.BlastXML
                 Bio.Alignment.AlignData Bio.Alignment.Matrices Bio.Alignment.SAlign
                 Bio.Alignment.AAlign Bio.Alignment.QAlign Bio.Alignment.Multiple
                 Bio.Alignment.ACE Bio.Alignment.Bowtie Bio.Alignment.Soap
                 Bio.Clustering Bio.Util Bio.Util.Parsex Bio.Util.TestBase
                 Bio.Location.Strand Bio.Location.Position
                 Bio.Location.ContigLocation Bio.Location.Location
                 Bio.Location.LocMap Bio.Location.OnSeq Bio.Location.SeqLocation
                 Bio.Location.SeqLocMap Bio.GFF3.Escape Bio.GFF3.Feature
                 Bio.GFF3.FeatureHier Bio.GFF3.FeatureHierSequences Bio.GFF3.SGD
hidden-modules:
import-dirs: /usr/local/lib/bio-0.4/ghc-6.10.4
library-dirs: /usr/local/lib/bio-0.4/ghc-6.10.4 /usr/local/lib
hs-libraries: HSbio-0.4
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: QuickCheck-1.2.0.0 array-0.2.0.0 base-3.0.3.1
         binary-0.5.0.2 bytestring-0.9.1.4 containers-0.2.0.1 mtl-1.1.0.2
         old-time-1.0.0.2 parallel-1.1.0.1 parsec-2.1.0.1 random-1.0.0.1
         tagsoup-0.10
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/bio-0.4/html/bio.haddock
haddock-html: /usr/local/share/doc/bio-0.4/html' | /usr/local/bin/ghc-pkg update -
